==> v1.2.tar.gz: slackmail/slack/channels.py <==
#
# Copyright 2015 (c) Anna Schumaker
#
from . import api
from . import auth
from . import chat
from . import users


class Channel:
    def __init__(self, json):
        self.__id      = json.get("id", "0")
        self.__name    = json.get("name", "").title()
        self.__member  = json.get("is_member", False)
        self.__topic   = json["topic"].get("value", "").encode("utf-8").decode("latin-1")
        self.__purpose = json["purpose"].get("value", "").encode("utf-8").decode("latin-1")
        self.__unread  = json.get("unread_count", None)
        self.__last_ts = json.get("last_read", None)

    def __str__(self):
        topic=""
        if self.__topic != "":
            topic = "\nTopic: %s" % self.__topic
        return "%s: %s%s" % (self.__name, self.__purpose, topic)

    def fetch_info(self):
        json = info(self.__id)
        if json != None:
            self.__unread  = json.get("unread_count", None)
            self.__last_ts = json.get("last_read", None)

    def id(self):
        return self.__id

    def is_member(self):
        return self.__member

    def name(self):
        return self.__name

    def post(self, text):
        chat.postMessage(self.__id, text)

    def unread_count(self):
        if self.__unread == None:
            self.fetch_info()
        return self.__unread

    def read(self):
        if self.__last_ts == None:
            self.fetch_info()
        return history(self.__id, self.__last_ts);



def history(channel, timestamp):
    ret = api.call("channels.history", token = auth.token(), channel = channel, oldest = timestamp)
    if ret["ok"] == False:
        return None

    m_list = []
    for message in ret["messages"]:
        msg = chat.Message(message)
        if len(m_list) == 0:
            m_list += [ msg ]
        elif m_list[-1].user() == msg.user():
            m_list[-1].merge(msg)
        else:
            m_list += [ msg ]

    m_list.sort()

    if len(m_list) > 0:
        mark(channel, m_list[-1].ts())
    return m_list

def info(channel):
    ret = api.call("channels.info", token = auth.token(), channel = channel)
    if ret["ok"] == False:
        return None
    return ret["channel"]

def list():
    ret = api.call("channels.list", token = auth.token())
    if ret["ok"] == False:
        return None

    ch_list = []
    for channel in ret["channels"]:
        ch_list += [ Channel(channel) ]
    return ch_list

def mark(channel, timestamp):
    api.call("channels.mark", token = auth.token(), channel = channel, ts = timestamp)

==> v1.3.tar.gz: slackmail/slack/channels.py <==
#
# Copyright 2015 (c) Anna Schumaker
#
from . import api
from . import auth
from . import chat
from . import users


class Channel:
    def __init__(self, json):
        self.__id      = json.get("id", "0")
        self.__name    = json.get("name", "").title()
        self.__member  = json.get("is_member", False)
        self.__topic   = json["topic"].get("value", "").encode("utf-8").decode("latin-1")
        self.__purpose = json["purpose"].get("value", "").encode("utf-8").decode("latin-1")
        self.__unread  = json.get("unread_count", None)
        self.__last_ts = json.get("last_read", None)

    def __str__(self):
        topic=""
        if self.__topic != "":
            topic = "\nTopic: %s" % self.__topic
        return "%s: %s%s" % (self.__name, self.__purpose, topic)

    def fetch_info(self):
        json = info(self.__id)
        if json != None:
            self.__unread  = json.get("unread_count", None)
            self.__last_ts = json.get("last_read", None)

    def id(self):
        return self.__id

    def is_member(self):
        return self.__member

    def name(self):
        return self.__name

    def post(self, text):
        chat.postMessage(self.__id, text)

    def unread_count(self):
        if self.__unread == None:
            self.fetch_info()
        return self.__unread

    def read(self):
        if self.__last_ts == None:
            self.fetch_info()
        return history(self.__id, self.__last_ts)



def history(channel, timestamp):
    ret = api.call("channels.history", token = auth.token(), channel = channel, oldest = timestamp)
    if ret["ok"] == False:
        return None

    # Read original message list
    o_list = []
    for message in ret["messages"]:
        o_list += [ chat.Message(message) ]
    o_list.sort()

    # Merge together messages from the same user
    m_list = [ o_list[0] ]
    for msg in o_list[1:]:
        if msg.user() == m_list[-1].user():
            m_list[-1].merge(msg)
        else:
            m_list += [ msg ]

    if len(m_list) > 0:
        mark(channel, m_list[-1].ts())
    return m_list

def info(channel):
    ret = api.call("channels.info", token = auth.token(), channel = channel)
    if ret["ok"] == False:
        return None
    return ret["channel"]

def list():
    ret = api.call("channels.list", token = auth.token())
    if ret["ok"] == False:
        return None

    ch_list = []
    for channel in ret["channels"]:
        ch_list += [ Channel(channel) ]
    return ch_list

def mark(channel, timestamp):
    api.call("channels.mark", token = auth.token(), channel = channel, ts = timestamp)
